@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: xfce-itembar.c 22697 2006-08-09 18:36:00Z jasper $
+/*  $Id: xfce-itembar.c 23200 2006-09-24 08:57:47Z jasper $
  *
  *  Copyright © 2004-2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -53,7 +53,7 @@ enum
 enum
 {
     PROP_0,
-    PROP_ORIENTATION,
+    PROP_ORIENTATION
 };
 
 enum
@@ -185,6 +185,7 @@ xfce_itembar_get_type (void)
 	    sizeof (XfceItembar),
 	    0,			/* n_preallocs */
 	    (GInstanceInitFunc) xfce_itembar_init,
+            NULL
 	};
 
 	type = g_type_register_static (GTK_TYPE_CONTAINER, "XfceItembar", 
