@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: launcher.c 23356 2006-10-11 19:10:40Z jasper $
+/*  $Id: launcher.c 24104 2006-12-14 18:56:25Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -736,20 +736,21 @@ launcher_update_panel_entry (LauncherPlugin *launcher)
     gtk_image_set_from_pixbuf (GTK_IMAGE (launcher->image), pb);
     g_object_unref (G_OBJECT (pb));
     
-    if (entry->name)
+    if (entry->name || entry->comment)
     {
-        if (entry->comment)
+        if (entry->name && entry->comment)
             g_snprintf (tip, 521, "%s\n%s", entry->name, entry->comment);
-        else
+        else if (entry->name)
             g_strlcpy (tip, entry->name, 521);
+        else
+            g_strlcpy (tip, entry->comment, 521);
 
+        gtk_tooltips_set_tip (launcher->tips, launcher->iconbutton, tip, NULL);
     }
     else
     {
-        g_strlcpy (tip, _("This item has not yet been configured"), 512);
+        gtk_tooltips_set_tip (launcher->tips, launcher->iconbutton, NULL, NULL);
     }
-
-    gtk_tooltips_set_tip (launcher->tips, launcher->iconbutton, tip, NULL);
 }
 
 static void
@@ -798,9 +799,9 @@ launcher_position_menu (GtkMenu * menu, int *x, int *y, gboolean * push_in,
     }
 
     screen = gtk_widget_get_screen (widget);
-
     num = gdk_screen_get_monitor_at_window (screen, widget->window);
 
+    gtk_menu_set_screen (menu, screen); 
     gdk_screen_get_monitor_geometry (screen, num, &geom);
 
     if (*x > geom.x + geom.width - req.width)
