@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: tasklist.c 22739 2006-08-13 09:10:57Z jasper $
+/*  $Id: tasklist.c 24245 2007-01-02 19:25:57Z nick $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -28,6 +28,7 @@
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/xfce-hvbox.h>
 
 typedef struct
 {
@@ -35,7 +36,6 @@ typedef struct
 
     GtkWidget *box;
     GtkWidget *handle;
-    GtkWidget *handle2;
     GtkWidget *list;
 
     int width;
@@ -72,28 +72,9 @@ tasklist_orientation_changed (XfcePanelPlugin *plugin,
                               GtkOrientation orientation, 
                               Tasklist *tasklist)
 {
-    GtkWidget *box;
-
-    box = (orientation == GTK_ORIENTATION_HORIZONTAL) ?
-            gtk_hbox_new (FALSE, 0) : gtk_vbox_new (FALSE, 0);
-    gtk_container_set_reallocate_redraws (GTK_CONTAINER (box), TRUE);
-    gtk_widget_show (box);
-
-    gtk_widget_reparent (tasklist->handle, box);
-    gtk_box_set_child_packing (GTK_BOX (box), tasklist->handle,
-                               FALSE, FALSE, 0, GTK_PACK_START);
-    gtk_widget_reparent (tasklist->list, box);
-    gtk_widget_reparent (tasklist->handle2, box);
-    gtk_box_set_child_packing (GTK_BOX (box), tasklist->handle2,
-                               FALSE, FALSE, 0, GTK_PACK_START);
-
-    gtk_widget_destroy (tasklist->box);
-    tasklist->box = box;
-    
-    gtk_container_add (GTK_CONTAINER (plugin), box);
+    xfce_hvbox_set_orientation (XFCE_HVBOX (tasklist->box), orientation);
 
     gtk_widget_queue_draw (tasklist->handle);
-    gtk_widget_queue_draw (tasklist->handle2);
 }
 
 static gboolean 
@@ -213,17 +194,33 @@ handle_expose (GtkWidget *widget, GdkEventExpose *ev, Tasklist *tasklist)
     {
         GtkAllocation *allocation = &(widget->allocation);
         int x, y, w, h;
+        gboolean horizontal;
 
-        x = allocation->x + widget->style->xthickness;
-        y = allocation->y + widget->style->ythickness;
-        w = allocation->width - 2 * widget->style->xthickness;
-        h = allocation->height - 2 * widget->style->ythickness;
+        horizontal = (xfce_panel_plugin_get_orientation (tasklist->plugin) 
+                      == GTK_ORIENTATION_HORIZONTAL);
 
-        gtk_paint_box (widget->style, widget->window, 
-                       GTK_WIDGET_STATE (widget),
-                       GTK_SHADOW_OUT,
-                       &(ev->area), widget, "xfce-panel",
-                       x, y, w, h);        
+        x = allocation->x;
+        y = allocation->y;
+        w = allocation->width;
+        h = allocation->height;
+        
+        if (horizontal)
+        {
+            y += widget->style->ythickness;
+            h -= 2 * widget->style->ythickness;
+        }
+        else
+        {
+            x += widget->style->xthickness;
+            w -= 2 * widget->style->xthickness;
+        }
+
+        gtk_paint_handle (widget->style, widget->window,
+                          GTK_WIDGET_STATE (widget), GTK_SHADOW_NONE, 
+                          &(ev->area), widget, "handlebox",
+                          x, y, w, h,
+                          horizontal ? GTK_ORIENTATION_VERTICAL :
+                                       GTK_ORIENTATION_HORIZONTAL);
 
         return TRUE;
     }
@@ -235,11 +232,16 @@ static void
 tasklist_screen_changed (GtkWidget *plugin, GdkScreen *screen, 
                          Tasklist *tasklist)
 {
-    if (!screen)
-        return;
+    NetkScreen *ns;
 
-    netk_tasklist_set_screen (NETK_TASKLIST (tasklist->list), 
-            netk_screen_get (gdk_screen_get_number (screen)));
+    screen = gtk_widget_get_screen (plugin);
+
+    if (G_UNLIKELY (screen == NULL))
+        screen = gdk_screen_get_default ();
+
+    ns = netk_screen_get (gdk_screen_get_number (screen));
+
+    netk_tasklist_set_screen (NETK_TASKLIST (tasklist->list), ns);
 }
 
 static void 
@@ -271,15 +273,14 @@ tasklist_construct (XfcePanelPlugin *plugin)
 
     xfce_panel_plugin_set_expand (plugin, tasklist->expand);
     
-    tasklist->box = (xfce_panel_plugin_get_orientation (plugin) == 
-                        GTK_ORIENTATION_HORIZONTAL) ?
-                    gtk_hbox_new (FALSE, 0) : gtk_vbox_new (FALSE, 0);
+    tasklist->box = xfce_hvbox_new (xfce_panel_plugin_get_orientation (plugin), 
+                                    FALSE, 0);
     gtk_container_set_reallocate_redraws (GTK_CONTAINER (tasklist->box), TRUE);
     gtk_widget_show (tasklist->box);
     gtk_container_add (GTK_CONTAINER (plugin), tasklist->box);
 
     tasklist->handle = gtk_alignment_new (0, 0, 0, 0);
-    gtk_widget_set_size_request (tasklist->handle, 6, 6);
+    gtk_widget_set_size_request (tasklist->handle, 8, 8);
     gtk_widget_show (tasklist->handle);
     gtk_box_pack_start (GTK_BOX (tasklist->box), tasklist->handle, 
                         FALSE, FALSE, 0);
@@ -296,17 +297,6 @@ tasklist_construct (XfcePanelPlugin *plugin)
     gtk_box_pack_start (GTK_BOX (tasklist->box), tasklist->list, 
                         TRUE, TRUE, 0);
             
-    tasklist->handle2 = gtk_alignment_new (0, 0, 0, 0);
-    gtk_widget_set_size_request (tasklist->handle2, 6, 6);
-    gtk_widget_show (tasklist->handle2);
-    gtk_box_pack_start (GTK_BOX (tasklist->box), tasklist->handle2, 
-                        FALSE, FALSE, 0);
-
-    xfce_panel_plugin_add_action_widget (plugin, tasklist->handle2);
-
-    g_signal_connect (tasklist->handle2, "expose-event", 
-                      G_CALLBACK (handle_expose), tasklist);
-
     netk_tasklist_set_include_all_workspaces (NETK_TASKLIST (tasklist->list), 
                                               tasklist->all_workspaces);
 
@@ -408,6 +398,9 @@ tasklist_properties_dialog (XfcePanelPlugin *plugin, Tasklist *tasklist)
                 GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
                 NULL);
 
+    gtk_window_set_screen (GTK_WINDOW (dlg), 
+                           gtk_widget_get_screen (GTK_WIDGET (plugin)));
+
     g_object_set_data (G_OBJECT (plugin), "dialog", dlg);
 
     gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
